@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Takvim",
-    "To-dos" : "Yapılacak işler",
+    "Tasks" : "Görevler",
     "Personal" : "Kişisel",
     "{actor} created calendar {calendar}" : "{actor}, {calendar} takvimini ekledi",
     "You created calendar {calendar}" : "{calendar} takvimini eklediniz",
@@ -72,27 +72,104 @@ OC.L10N.register(
     "Description: %s" : "Açıklama: %s",
     "Where: %s" : "Şurada: %s",
     "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
+    "In a %1$s on %2$s for the entire day" : "Tüm gün boyunca %1$s içinde %2$s zamanında",
+    "In a %1$s on %2$s between %3$s - %4$s" : "%1$s içinde %2$s zamanında %3$sile %4$s arasında",
+    "In %1$s %2$s on %3$s for the entire day" : "Tüm gün boyunca %1$s %2$s içinde %3$s zamanında",
+    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s %2$s içinde %3$s zamanında %4$s ile %5$s arasında",
+    "Could not generate when statement" : "Zaman ifadesi oluşturulamadı",
+    "Every Day for the entire day" : "Her gün tüm gün boyunca",
+    "Every Day for the entire day until %1$s" : "%1$s zamanına kadar her gün tüm gün boyunca",
+    "Every Day between %1$s - %2$s" : "Her gün %1$s ile %2$s arasında",
+    "Every Day between %1$s - %2$s until %3$s" : "%3$s zamanına kadar %1$s ile %2$s arasında her gün",
+    "Every %1$d Days for the entire day" : "Her %1$d günde tüm gün boyunca",
+    "Every %1$d Days for the entire day until %2$s" : "%2$s zamanına kadar her %1$d günde tüm gün boyunca",
+    "Every %1$d Days between %2$s - %3$s" : "Her %1$d günde %2$s ile %3$s arasında",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "%4$s zamanına kadar her %1$d günde %2$s ile %3$s",
+    "Could not generate event recurrence statement" : "Etkinlik yinelenme ifadesi oluşturulamadı",
+    "Every Week on %1$s for the entire day" : "Her hafta %1$s tüm gün boyunca",
+    "Every Week on %1$s for the entire day until %2$s" : "Her hafta %1$s tüm gün boyunca %2$s zamanına kadar",
+    "Every Week on %1$s between %2$s - %3$s" : "Her hafta %1$s %2$s ile %3$s arasında",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Her hafta %1$s %2$s ile %3$s arasında %4$s zamanına kadar",
+    "Every %1$d Weeks on %2$s for the entire day" : "Her %1$d haftada bir %2$s tüm gün boyunca",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Her %1$d haftada bir %2$s tüm gün boyunca %3$s zamanına kadar",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Her %1$d haftada bir %2$s tüm gün boyunca %3$s ile %4$s arasında",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Her %1$d haftada bir %2$s %3$s ile %4$s arasında %5$s zamanına kadar",
+    "Every Month on the %1$s for the entire day" : "Her ay %1$s tüm gün boyunca",
+    "Every Month on the %1$s for the entire day until %2$s" : "Her ay %1$s tüm gün boyunca %2$s zamanına kadar",
+    "Every Month on the %1$s between %2$s - %3$s" : "Her ay %1$s %2$s ile %3$s arasında",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Her ay %1$s %2$s ile %3$s arasında %4$s zamanına kadar",
+    "Every %1$d Months on the %2$s for the entire day" : "Her %1$d ayda bir %2$s tüm gün boyunca",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Her %1$d ayda bir %2$s tüm gün boyunca %3$s zamanına kadar",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Her %1$d ayda bir %2$s tüm gün boyunca %3$s ile %4$s arasında",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Her %1$d ayda bir %2$s %3$s ile %4$s arasında %5$s zamanına kadar",
+    "Every Year in %1$s on the %2$s for the entire day" : "Her yıl %1$s ayında %2$s tüm gün boyunca",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Her yıl %1$s ayında %2$s tüm gün boyunca %3$s zamanına kadar",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Her yıl %1$s ayında %2$s tüm gün boyunca %3$s ile %4$s arasında",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Her yıl %1$s ayında %2$s %3$s ile %4$s arasında %5$s zamanına kadar",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Her %1$d yılda bir %2$s ayında %3$s tüm gün boyunca",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Her %1$d yılda bir %2$s ayında %3$s tüm gün boyunca %4$s zamanına kadar",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Her %1$d yılda bir %2$s ayında %3$s tüm gün boyunca %4$s ile %5$s arasında",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Her %1$d yılda bir %2$s ayında %3$s %4$s ile %5$s arasında %6$s zamanına kadar",
+    "On specific dates for the entire day until %1$s" : "Belirli tarihlerde tüm gün boyunca %1$s zamanına kadar",
+    "On specific dates between %1$s - %2$s until %3$s" : "Belirli günlerde %1$s ile %2$s arasında %3$s zamanına kadar",
+    "In a %1$s on %2$s" : "%1$s içinde %2$s",
+    "In a %1$s on %2$s then on %3$s" : "%1$s içinde %2$s ve %3$s",
+    "In a %1$s on %2$s then on %3$s and %4$s" : "%1$s içinde %2$s, %3$s ve %4$s",
+    "In %1$s %2$s on %3$s" : "%1$s %2$s içinde %3$s",
+    "In %1$s %2$s on %3$s then on %4$s" : "%1$s %2$s içinde %3$s ve %4$s",
+    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "%1$s %2$s içinde %3$s, %4$s ve %5$s",
+    "Could not generate next recurrence statement" : "Sonraki yinelenme ifadesi oluşturulamadı",
     "Cancelled: %1$s" : "İptal edildi: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" iptal edildi",
     "Re: %1$s" : "Ynt: %1$s",
-    "%1$s has accepted your invitation" : "%1$s çağrınızı kabul etti",
-    "%1$s has tentatively accepted your invitation" : "%1$s çağrınızı belirsiz olarak kabul etti",
-    "%1$s has declined your invitation" : "%1$s çağrınızı reddetti.",
-    "%1$s has responded to your invitation" : "%1$s çağrınızı yanıtladı",
-    "Invitation updated: %1$s" : "Çağrı güncellendi: %1$s",
+    "%1$s has accepted your invitation" : "%1$s davetinizi kabul etti",
+    "%1$s has tentatively accepted your invitation" : "%1$s davetinizi belirsiz olarak kabul etti",
+    "%1$s has declined your invitation" : "%1$s davetinizi reddetti.",
+    "%1$s has responded to your invitation" : "%1$s davetinizi yanıtladı",
+    "Invitation updated: %1$s" : "Davet güncellendi: %1$s",
     "%1$s updated the event \"%2$s\"" : "%1$s, \"%2$s\" etkinliğini güncelledi",
-    "Invitation: %1$s" : "Çağrı: %1$s",
-    "%1$s would like to invite you to \"%2$s\"" : "%1$s, size \"%2$s\" için çağrı gönderdi",
+    "Invitation: %1$s" : "Davet: %1$s",
+    "%1$s would like to invite you to \"%2$s\"" : "%1$s, size \"%2$s\" için davet gönderdi",
     "Organizer:" : "Düzenleyen:",
     "Attendees:" : "Katılımcılar:",
     "Title:" : "Başlık:",
-    "Time:" : "Zaman:",
+    "When:" : "Zaman:",
     "Location:" : "Konum:",
     "Link:" : "Bağlantı:",
+    "Occurring:" : "Başlangıç:",
     "Accept" : "Kabul et",
     "Decline" : "Reddet",
     "More options …" : "Diğer seçenekler …",
     "More options at %s" : "%s üzerindeki diğer seçenekler",
+    "Monday" : "Pazartesi",
+    "Tuesday" : "Salı",
+    "Wednesday" : "Çarşamba",
+    "Thursday" : "Perşembe",
+    "Friday" : "Cuma",
+    "Saturday" : "Cumartesi",
+    "Sunday" : "Pazar",
+    "January" : "Ocak",
+    "February" : "Şubat",
+    "March" : "Mart",
+    "April" : "Nisan",
+    "May" : "Mayıs",
+    "June" : "Haziran",
+    "July" : "Temmuz",
+    "August" : "Ağustos",
+    "September" : "Eylül",
+    "October" : "Ekim",
+    "November" : "Kasım",
+    "December" : "Aralık",
+    "First" : "İlk",
+    "Second" : "İkinci",
+    "Third" : "Üçüncü",
+    "Fourth" : "Dördüncü",
+    "Fifty" : "Beşinci",
+    "Last" : "Son",
+    "Second Last" : "İkinci son",
+    "Third Last" : "Üçüncü son",
+    "Fourth Last" : "Dördüncü son",
+    "Fifty Last" : "Beşinci son",
     "Contacts" : "Kişiler",
     "{actor} created address book {addressbook}" : "{actor}, {addressbook} adres defterini ekledi",
     "You created address book {addressbook}" : "{addressbook} adres defterini eklediniz",
@@ -121,6 +198,7 @@ OC.L10N.register(
     "Accounts" : "Hesaplar",
     "System address book which holds all accounts" : "Tüm hesapların bulunduğu sistem adres defteri",
     "File is not updatable: %1$s" : "Dosya güncellenebilir değil: %1$s",
+    "Failed to get storage for file" : "Dosyanın depolaması alınamadı",
     "Could not write to final file, canceled by hook" : "Sonuç dosyasına yazılamadı, bağlantı tarafından iptal edildi",
     "Could not write file contents" : "Dosya içerikleri yazılamadı",
     "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
@@ -133,62 +211,81 @@ OC.L10N.register(
     "Encryption not ready: %1$s" : "Şifreleme hazır değil: %1$s",
     "Failed to open file: %1$s" : "Dosya açılamadı: %1$s",
     "Failed to unlink: %1$s" : "Bağlantı kaldırılamadı: %1$s",
-    "Invalid chunk name" : "Parça adı geçersiz",
-    "Could not rename part file assembled from chunks" : "Parçalardan oluşturulan parça dosyası yeniden adlandırılamadı ",
     "Failed to write file contents: %1$s" : "Dosya içerikleri yazılamadı: %1$s",
     "File not found: %1$s" : "Dosya bulunamadı: %1$s",
+    "Invalid target path" : "Hedef yol geçersiz",
     "System is in maintenance mode." : "Sistem bakım kipinde.",
     "Upgrade needed" : "Yükseltme gerekiyor",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS üzerinde CalDAV ve CardDAV kullanabilmek için %s HTTPS kullanacak şekilde yapılandırılmalıdır.",
     "Configures a CalDAV account" : "Bir CalDAV hesabı yapılandırır",
     "Configures a CardDAV account" : "Bir CardDAV hesabı yapılandırır",
     "Events" : "Etkinlikler",
-    "Tasks" : "Görevler",
     "Untitled task" : "Adlandırılmamış görev",
     "Completed on %s" : "%s tarihinde tamamlandı",
     "Due on %s by %s" : "%s tarihine kadar %s tarafından",
     "Due on %s" : "%s tarihine kadar",
+    "DAV system address book" : "DAV sistem adres defteri",
+    "No outstanding DAV system address book sync." : "Bekleyen bir DAV sistemi adres defteri eşitlemesi yok.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Kopyanızda 1000 üzerinde kullanıcı olduğundan ya da bir sorun çıktığından DAV sistemi adres defteri eşitlemesi henüz yapılmamış. Lütfen \"occ dav:sync-system-addressbook\" komutunu yürüterek el ile eşitleyin.",
+    "WebDAV endpoint" : "WebDAV bağlantı noktası",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Site sunucunuzun WebDAV  üzerinden dosya eşitlemesi için doğru şekilde ayarlanıp ayarlanmadığı denetlenemedi. Lütfen el ile denetleyin.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Site sunucunuz dosya eşitlemesi için doğru şekilde ayarlanmamış. WebDAV arabirimi sorunlu görünüyor.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Site sunucunuz WebDAV  üzerinden dosya eşitlemesi için doğru şekilde ayarlanmış.",
     "Migrated calendar (%1$s)" : "Aktarılmış takvim (%1$s)",
     "Calendars including events, details and attendees" : "Etkinlikler, bilgiler ve katılımcılar ile takvimler",
     "Contacts and groups" : "Kişiler ve gruplar",
     "WebDAV" : "WebDAV",
-    "WebDAV endpoint" : "WebDAV bağlantı noktası",
-    "Availability" : "Uygunluk",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kullanıcılar bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler.",
+    "First day" : "İlk gün",
+    "Last day (inclusive)" : "Son gün (dahil)",
+    "Out of office replacement (optional)" : "Ofis dışındayken yerine bakacak kişi (isteğe bağlı)",
+    "Name of the replacement" : "Yerine bakacak kişi adı",
+    "No results." : "Herhangi bir sonuç bulunamadı.",
+    "Start typing." : "Yazmaya başlayın.",
+    "Short absence status" : "Kısa işe gelmeme durumu",
+    "Long absence Message" : "Uzun işe gelmeme iletisi",
+    "Save" : "Kaydet",
+    "Disable absence" : "İşe gelmemeyi kapat",
+    "Absence saved" : "İşe gelmeme kaydedildi",
+    "Failed to save your absence settings" : "İşe gelmeme ayarlarınız kaydedilemedi",
+    "Absence cleared" : "İşe gelmeme temizlendi",
+    "Failed to clear your absence settings" : "İşe gelmeme ayarlarınız temizlenemedi",
     "Time zone:" : "Saat dilimi:",
     "to" : "ile",
     "Delete slot" : "Aralığı sil",
     "No working hours set" : "Çalışma saatleri ayarlanmamış",
     "Add slot" : "Aralık ekle",
-    "Monday" : "Pazartesi",
-    "Tuesday" : "Salı",
-    "Wednesday" : "Çarşamba",
-    "Thursday" : "Perşembe",
-    "Friday" : "Cuma",
-    "Saturday" : "Cumartesi",
-    "Sunday" : "Pazar",
+    "Weekdays" : "Hafta içi günleri",
+    "Pick a start time for {dayName}" : "{dayName} için başlangıç zamanını seçin",
+    "Pick a end time for {dayName}" : "{dayName} için bitiş zamanını seçin",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Tüm bildirimleri sessize almak için, uygunluk durumu dışında kullanıcı durumu otomatik olarak \"Rahatsız etmeyin\" olarak ayarlanır.",
-    "Save" : "Kaydet",
     "Failed to load availability" : "Uygunluk yüklenemedi",
     "Saved availability" : "Uygunluk kaydedildi",
     "Failed to save availability" : "Uygunluk kaydedilemedi",
+    "Availability" : "Uygunluk",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kişiler bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler.",
+    "Absence" : "İşe gelmeme",
+    "Configure your next absence period." : "Sonraki işe gelmeme aralığınızı yapılandırın.",
     "Calendar server" : "Takvim sunucusu",
-    "Send invitations to attendees" : "Katılımcılara çağrılar gönderilsin",
+    "Send invitations to attendees" : "Katılımcılara davet gönder",
     "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
-    "Birthday calendars will be generated by a background job." : "Bu seçenek etkinleştirildiğinde, doğum günü takvimi arka plan görevi olarak oluşturulur.",
-    "Hence they will not be available immediately after enabling but will show up after some time." : "Etkinleştirildikten hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
+    "Birthday calendars will be generated by a background job." : "Bu seçenek kullanıma alındığında, doğum günü takvimi arka plan görevi olarak oluşturulur.",
+    "Hence they will not be available immediately after enabling but will show up after some time." : "Kullanıma alındıktan hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
     "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
     "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
     "Send reminder notifications to calendar sharees as well" : "Takvim paylaşımlarına da hatırlatma bildirimleri gönderilsin",
-    "Reminders are always sent to organizers and attendees." : "Bu seçenek etkinleştirildiğinde, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
-    "Enable notifications for events via push" : "Anında etkinlik bildirimleri kullanılsın",
+    "Reminders are always sent to organizers and attendees." : "Bu seçenek kullanıma alındığında, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
+    "Enable notifications for events via push" : "Anında etkinlik bildirimlerini aç",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
     "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
     "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
-    "Are you accepting the invitation?" : "Çağrıyı kabul ediyor musunuz?",
+    "Are you accepting the invitation?" : "Daveti kabul ediyor musunuz?",
     "Tentative" : "Kesin değil",
     "Your attendance was updated successfully." : "Katılımınız güncellendi.",
-    "%1$s has responded your invitation" : "%1$s çağrınızı yanıtladı"
+    "To-dos" : "Yapılacak işler",
+    "Time:" : "Zaman:",
+    "Invalid chunk name" : "Parça adı geçersiz",
+    "Could not rename part file assembled from chunks" : "Parçalardan oluşturulan parça dosyası yeniden adlandırılamadı ",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kullanıcılar bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler."
 },
 "nplurals=2; plural=(n > 1);");
