@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "ファイルを見つけられませんでした",
-    "Move or copy" : "移動またはコピー",
-    "Download" : "ダウンロード",
-    "Delete" : "削除",
-    "Tags" : "タグ",
-    "Show list view" : "リストビューで表示",
-    "Show grid view" : "グリッドビューで表示",
-    "Home" : "ホーム",
-    "Close" : "閉じる",
-    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
-    "This will stop your current uploads." : "現在のアップロードが停止されます。",
-    "Upload cancelled." : "アップロードはキャンセルされました。",
-    "Processing files …" : "ファイルの処理中...",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
-    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
-    "Not enough free space" : "十分な空き容量がありません",
-    "An unknown error has occurred" : "不明なエラーが発生しました",
-    "File could not be uploaded" : "ファイルをアップロードできませんでした",
-    "Uploading …" : "アップロード中...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "アップロード中… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
-    "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
-    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
-    "Operation is blocked by access control" : "アクセス制御により操作がブロックされました",
-    "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
-    "Actions" : "アクション",
-    "Rename" : "名前の変更",
-    "Move" : "移動",
-    "Copy" : "コピー",
-    "Choose target folder" : "ターゲットフォルダーを選択",
-    "Set reminder" : "リマインダーを設定",
-    "Edit locally" : "ローカルで編集",
-    "Open" : "開く",
-    "Delete file" : "ファイルを削除",
-    "Delete folder" : "フォルダーを削除",
-    "Disconnect storage" : "ストレージを切断する",
-    "Leave this share" : "この共有から抜ける",
-    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
-    "Files" : "ファイル",
-    "Details" : "詳細",
-    "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
-    "Apply tag(s) to selection" : "選択項目にタグを適用",
-    "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
-    "Select file \"{fileName}\"" : "ファイルを選択: \"{fileName}\"",
-    "Pending" : "保留中",
-    "Unable to determine date" : "更新日不明",
-    "This operation is forbidden" : "この操作は禁止されています",
-    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
-    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
-    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
-    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
-    "copy" : "コピー",
-    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
-    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
-    "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
-    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
-    "{newName} already exists" : "{newName} はすでに存在します",
-    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
-    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
-    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
-    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
-    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
-    "Could not fetch file details \"{file}\"" : "\"{file}\" の詳細が取得できませんでした",
-    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
-    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
-    "Enter more than two characters to search in other folders" : "他のフォルダーで検索するには、3文字以上を入力してください",
-    "Name" : "名前",
-    "Size" : "サイズ",
-    "Modified" : "更新日時",
-    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
-    "_%n file_::_%n files_" : ["%n 個のファイル"],
-    "{dirs} and {files}" : "{dirs} と {files}",
-    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
-    "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
-    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
-    "New" : "新規作成",
-    "New file/folder menu" : "新規ファイル/フォルダメニュー",
-    "Select file range" : "ファイルを範囲選択",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "{used} / {quota} 使用中",
-    "{used} used" : "{used} 使用中",
-    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
-    "File name cannot be empty." : "ファイル名を空にすることはできません。",
-    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はできません！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "グループフォルダー ”{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部ストレージ \"{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
-    "Your storage is full, files cannot be updated or synced anymore!" : "ストレージがいっぱいで、ファイルを更新または同期できなくなりました。",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} のストレージがほぼ一杯 ({usedSpacePercent}％) です",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "グループフォルダー \"{mountPoint}\" がほぼいっぱい ({usedSpacePercent}％) です。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部ストレージ \"{mountPoint}\" はほぼいっぱい ({usedSpacePercent}％) です",
-    "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
-    "View in folder" : "フォルダー内で表示",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "ダイレクトリンクがコピーされました（このファイルやフォルダにアクセスできる人にのみ機能します）",
-    "Path" : "Path",
-    "_%n byte_::_%n bytes_" : ["%n バイト"],
-    "Favorited" : "お気に入り済",
-    "Favorite" : "お気に入り",
-    "Copy direct link (only works for people who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダにアクセスできる人にのみ機能します)",
-    "New folder" : "新しいフォルダー",
-    "Create new folder" : "新しいフォルダーを作成",
-    "Upload file" : "ファイルをアップロード",
-    "Recent" : "最新",
-    "Not favorited" : "お気に入りではありません",
-    "Remove from favorites" : "お気に入りから削除",
-    "Add to favorites" : "お気に入りに追加",
-    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
     "Added to favorites" : "お気に入りに追加",
     "Removed from favorites" : "お気に入りから削除",
     "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
@@ -154,16 +40,13 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
     "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
     "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
+    "Files" : "ファイル",
     "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーが<strong>変更</strong>されたとき",
     "A favorite file or folder has been <strong>changed</strong>" : "お気に入りのファイルまたはフォルダーが <strong>変更</strong>されたとき",
     "Failed to authorize" : "認証に失敗しました",
     "Invalid folder path" : "無効なフォルダーパス",
     "Folder not found" : "フォルダーが見つかりません",
     "Upload (max. %s)" : "アップロード ( 最大 %s )",
-    "Files compatibility" : "ファイルの互換性",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ファイルをすべてのクライアントと同期できるようにするために、ファイル名を制限することを許可します。デフォルトではPOSIX（LinuxやmacOSなど）で有効なすべてのファイル名が許可されています。",
-    "Enforce Windows compatibility" : "Windowsとの互換性を強制",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "予約名や特殊文字のような、Windowsシステムにおいて有効でないファイル名をブロックします。これは大文字、小文字の互換性を強制するものではありません。",
     "Accept" : "承諾",
     "Reject" : "拒否",
     "Incoming ownership transfer from {user}" : "{user} からの所有権転送を受信",
@@ -178,13 +61,20 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{user} からの {path} の所有権転送が完了しました。",
     "in %s" : "%s で",
     "Transferred from %1$s on %2$s" : "%1$sから%2$sに転送",
+    "Files compatibility" : "ファイルの互換性",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ファイルをすべてのクライアントと同期できるようにするために、ファイル名を制限することを許可します。デフォルトではPOSIX（LinuxやmacOSなど）で有効なすべてのファイル名が許可されています。",
+    "Enforce Windows compatibility" : "Windowsとの互換性を強制",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "予約名や特殊文字のような、Windowsシステムにおいて有効でないファイル名をブロックします。これは大文字、小文字の互換性を強制するものではありません。",
     "File Management" : "ファイル管理",
     "Current directory path" : "現在のディレクトリパス",
+    "Home" : "ホーム",
+    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
     "Reload current directory" : "カレントディレクトリの再読み込み",
     "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
     "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
     "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
     "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
+    "Favorite" : "お気に入り",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行された",
     "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
     "Toggle selection for file \"{displayName}\"" : "ファイル \"{displayName}\" の選択を切り替える",
@@ -198,15 +88,18 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "同じ名前の別のエントリがすでに存在しています。",
     "Invalid filename." : "無効なファイル名。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
-    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" という名前は \"{dir}\" フォルダですでに使用されています。別の名前を選択してください。",
-    "Could not rename \"{oldName}\"" : "\"{oldName}\" の名前を変更できませんでした。",
+    "Pending" : "保留中",
     "Clear filter" : "フィルターをクリア",
+    "Modified" : "更新日時",
     "Type" : "タイプ",
     "Active filters" : "有効なフィルター",
     "Remove filter" : "フィルターを削除",
     "Total rows summary" : "総行数のサマリー",
+    "Name" : "名前",
+    "Size" : "サイズ",
     "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
+    "Actions" : "アクション",
+    "(selected)" : "(選択済み)",
     "\"{displayName}\" failed on some elements " : "いくつかの要素で \"{displayName}\" が失敗しました。",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
     "{count} selected" : "{count} 選択",
@@ -217,10 +110,13 @@ OC.L10N.register(
     "Storage information" : "ストレージ情報",
     "Storage quota" : "ストレージのクォータ",
     "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
+    "{used} of {quota} used" : "{used} / {quota} 使用中",
     "{relative}% used" : "{relative}% 使用されています",
     "Could not refresh storage stats" : "ストレージの状態を更新できませんでした",
     "Your storage is full, files can not be updated or synced anymore!" : "ストレージは一杯です。ファイルの更新と同期はできません！",
     "Create" : "作成",
+    "New folder" : "新しいフォルダー",
+    "Create new folder" : "新しいフォルダーを作成",
     "This name is already in use." : "この名前は既に使用されています。",
     "Fill template fields" : "テンプレートフィールドへの入力",
     "Submitting fields…" : "フィールドを送信中…",
@@ -237,12 +133,12 @@ OC.L10N.register(
     "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
     "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
     "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
-    "Choose file" : "ファイルを選択",
     "Choose {file}" : "{file}を選択",
+    "New" : "新規作成",
     "Loading current folder" : "現在のフォルダの読み込み中",
+    "Retry" : "リトライ",
     "No files in here" : "ファイルがありません",
     "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
-    "Go to the previous folder" : "前のフォルダへ移動",
     "Go back" : "戻る",
     "Share" : "共有",
     "Shared by link" : "URLリンクで共有中",
@@ -250,6 +146,8 @@ OC.L10N.register(
     "Switch to list view" : "リスト表示へ切り替え",
     "Switch to grid view" : "グリッド表示へ切り替え",
     "Upload was cancelled by user" : "アップロードはユーザーによってキャンセルされました",
+    "Not enough free space" : "十分な空き容量がありません",
+    "Operation is blocked by access control" : "アクセス制御により操作がブロックされました",
     "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
     "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
     "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
@@ -274,6 +172,12 @@ OC.L10N.register(
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
     "Clipboard is not available" : "クリップボードは利用できません",
     "WebDAV URL copied to clipboard" : "WebDAVのURLがクリップボードにコピーされました",
+    "Owner" : "作成者",
+    "Remove from favorites" : "お気に入りから削除",
+    "Add to favorites" : "お気に入りに追加",
+    "Tags" : "タグ",
+    "You" : "自分",
+    "Shared multiple times with different people" : "異なる人と複数回共有",
     "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
     "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
     "Pick a template for {name}" : "{name} のテンプレートを選択してください",
@@ -284,10 +188,15 @@ OC.L10N.register(
     "Deletion cancelled" : "削除はキャンセルされました",
     "Delete permanently" : "完全に削除する",
     "Delete and unshare" : "削除して共有を解除",
+    "Leave this share" : "この共有から抜ける",
     "Leave these shares" : "これらの共有から抜ける",
+    "Disconnect storage" : "ストレージを切断する",
     "Disconnect storages" : "ストレージを切断する",
+    "Delete file" : "ファイルを削除",
     "Delete files" : "ファイルの削除",
+    "Delete folder" : "フォルダーを削除",
     "Delete folders" : "フォルダを削除",
+    "Delete" : "削除",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}アイテムを完全に削除しようとしています"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["あなたは {count} 個のアイテムを削除しようとしています"],
     "Confirm deletion" : "削除の確認",
@@ -296,8 +205,10 @@ OC.L10N.register(
     "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "ファイルがローカルで開かれます。これが発生しない場合は、デスクトップクライアントがシステムにインストールされていることを確認してください。",
     "Retry local edit" : "ローカル編集を再試行する",
     "Edit online" : "オンラインで編集",
-    "Destination is not a folder" : "宛先がフォルダではありません",
-    "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
+    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
+    "Edit locally" : "ローカルで編集",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
     "(copy)" : "(copy)",
     "(copy %n)" : "(copy %n)",
@@ -307,13 +218,18 @@ OC.L10N.register(
     "The file does not exist anymore" : "ファイルはもう存在しません",
     "Choose destination" : "移動先を選択",
     "Copy to {target}" : "{target} にコピー",
+    "Copy" : "コピー",
     "Move to {target}" : "{target} に移動",
+    "Move" : "移動",
     "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
+    "Move or copy" : "移動またはコピー",
     "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"の移動またはコピーをキャンセルしました。",
     "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
     "Open folder {displayName}" : "フォルダ {displayName} を開く",
     "Open in Files" : "ファイルアプリで開く",
+    "Rename" : "名前の変更",
     "Open details" : "詳細を開く",
+    "View in folder" : "フォルダー内で表示",
     "Today" : "今日",
     "Last 7 days" : "7日以内",
     "Last 30 days" : "30日以内",
@@ -348,6 +264,10 @@ OC.L10N.register(
     "Files moved successfully" : "ファイルの移動に成功しました",
     "Conflicts resolution skipped" : "コンフリクトの解決はスキップされました",
     "Upload cancelled" : "アップロードはキャンセルされました",
+    "This operation is forbidden" : "この操作は禁止されています",
+    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
+    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
+    "Unexpected error: {error}" : "予期せぬエラー: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} フォルダ"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ファイル"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ファイルと {folderCount} フォルダ"],
@@ -358,7 +278,7 @@ OC.L10N.register(
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\"は予約名であり、ファイル名には使用できません。",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" は許可されたファイルタイプではありません。",
     "Filenames must not end with \"{extension}\"." : "ファイル名は \"{extension}\"で終了できません。",
-    "List of favorites files and folders." : "お気に入りのファイルやフォルダーの一覧",
+    "List of favorite files and folders." : "お気に入りのファイルやフォルダーの一覧",
     "No favorites yet" : "まだお気に入りはありません",
     "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
     "All files" : "すべてのファイル",
@@ -368,17 +288,94 @@ OC.L10N.register(
     "List of your files and folders that are not shared." : "共有されていないファイルやフォルダの一覧。",
     "No personal files found" : "個人ファイルは見つかりませんでした",
     "Files that are not shared will show up here." : "共有されていないファイルは、ここに表示されます。",
+    "Recent" : "最新",
     "List of recently modified files and folders." : "最近変更されたファイルとフォルダーのリスト",
     "No recently modified files" : "最近更新されたファイルはありません",
     "Files and folders you recently modified will show up here." : "最近変更したファイルやフォルダーがここに表示されます。",
+    "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
     "No entries found in this folder" : "このフォルダーにはエントリーがありません",
     "Select all" : "すべて選択",
     "Upload too large" : "アップロードには大きすぎます。",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
-    "Text file" : "テキストファイル",
-    "New text file.txt" : "新規のテキストファイル作成",
+    "File could not be found" : "ファイルを見つけられませんでした",
+    "Download" : "ダウンロード",
+    "Show list view" : "リストビューで表示",
+    "Show grid view" : "グリッドビューで表示",
+    "Close" : "閉じる",
+    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
+    "This will stop your current uploads." : "現在のアップロードが停止されます。",
+    "Upload cancelled." : "アップロードはキャンセルされました。",
+    "Processing files …" : "ファイルの処理中...",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
+    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
+    "An unknown error has occurred" : "不明なエラーが発生しました",
+    "File could not be uploaded" : "ファイルをアップロードできませんでした",
+    "Uploading …" : "アップロード中...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "アップロード中… ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
+    "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
+    "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
+    "Choose target folder" : "ターゲットフォルダーを選択",
+    "Set reminder" : "リマインダーを設定",
+    "Open" : "開く",
+    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
+    "Details" : "詳細",
+    "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
+    "Apply tag(s) to selection" : "選択項目にタグを適用",
+    "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
+    "Select file \"{fileName}\"" : "ファイルを選択: \"{fileName}\"",
+    "Unable to determine date" : "更新日不明",
+    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
+    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
+    "copy" : "コピー",
+    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
+    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
+    "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
+    "{newName} already exists" : "{newName} はすでに存在します",
+    "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
+    "Could not rename \"{fileName}\"" : "\"{fileName}\"の名前変更ができませんでした",
+    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
+    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
+    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
+    "Could not fetch file details \"{file}\"" : "\"{file}\" の詳細が取得できませんでした",
+    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
+    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
+    "Enter more than two characters to search in other folders" : "他のフォルダーで検索するには、3文字以上を入力してください",
+    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
+    "_%n file_::_%n files_" : ["%n 個のファイル"],
+    "{dirs} and {files}" : "{dirs} と {files}",
+    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
+    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
+    "New file/folder menu" : "新規ファイル/フォルダメニュー",
+    "Select file range" : "ファイルを範囲選択",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} 使用中",
+    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
+    "File name cannot be empty." : "ファイル名を空にすることはできません。",
+    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はできません！",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "グループフォルダー ”{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部ストレージ \"{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
+    "Your storage is full, files cannot be updated or synced anymore!" : "ストレージがいっぱいで、ファイルを更新または同期できなくなりました。",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} のストレージがほぼ一杯 ({usedSpacePercent}％) です",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "グループフォルダー \"{mountPoint}\" がほぼいっぱい ({usedSpacePercent}％) です。",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部ストレージ \"{mountPoint}\" はほぼいっぱい ({usedSpacePercent}％) です",
+    "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
     "Direct link was copied (only works for users who have access to this file/folder)" : "直接リンクがコピーされました（ただしこのファイルやフォルダにアクセスできる人だけが使用可能です）",
+    "Path" : "Path",
+    "_%n byte_::_%n bytes_" : ["%n バイト"],
+    "Favorited" : "お気に入り済",
     "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
+    "Upload file" : "ファイルをアップロード",
+    "Not favorited" : "お気に入りではありません",
+    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
     "\"remote user\"" : "\"リモートユーザー\"",
     "{newName} already exists." : "{newName} すでに存在しています。",
     "\"{segment}\" is not allowed inside a filename." : "\"{segment}\"はファイル名には使用できません。",
@@ -387,11 +384,24 @@ OC.L10N.register(
     "Filenames must not end with \"{segment}\"." : "ファイル名は \"{segment}\"で終了できません。",
     "Name cannot be empty" : "名前は空にできません",
     "Another entry with the same name already exists" : "同じ名前の別のエントリがすでに存在しています",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" という名前は \"{dir}\" フォルダですでに使用されています。別の名前を選択してください。",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" の名前を変更できませんでした。",
     "Storage informations" : "ストレージ情報",
+    "Choose file" : "ファイルを選択",
+    "Go to the previous folder" : "前のフォルダへ移動",
     "Open the files app settings" : "ファイルアプリの設定を開く",
     "You might not have have permissions to view it, ask the sender to share it" : "閲覧権限がない可能性があるため、送信者に共有を依頼してください",
     "The files is locked" : "ファイルはロックされています",
     "Create new templates folder" : "新しいテンプレートフォルダーを作成",
-    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え"
+    "List of favorites files and folders." : "お気に入りのファイルやフォルダーの一覧",
+    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
+    "Text file" : "テキストファイル",
+    "New text file.txt" : "新規のテキストファイル作成",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "ダイレクトリンクがコピーされました（このファイルやフォルダにアクセスできる人にのみ機能します）",
+    "Copy direct link (only works for people who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダにアクセスできる人にのみ機能します)",
+    "Favored" : "好評",
+    "Favor" : "好意的",
+    "Not favored" : "好ましくない"
 },
 "nplurals=1; plural=0;");
