@@ -119,7 +119,6 @@ OC.L10N.register(
     "Personal info" : "개인 정보",
     "Mobile & desktop" : "모바일 & 데스크톱",
     "Email server" : "이메일 서버",
-    "Security & setup warnings" : "보안 및 설치 경고",
     "Background jobs" : "배경 작업",
     "Unlimited" : "무제한",
     "Verifying" : "검사",
@@ -161,8 +160,6 @@ OC.L10N.register(
     "Email test" : "이메일 시험",
     "Email test was successfully sent" : "시험 이메일이 성공적으로 전송됨",
     "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "이메일 서버 설정이 입력되지 않았거나 검증되지 않았습니다. \"기본 설정\"으로 이동해 설정을 완료하십시오. 서버 정보를 입력한 후 양식 아래 \"이메일 발송\" 버튼을 눌러 설정을 검증하십시오.",
-    "File locking" : "파일 잠금",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 방지하십시오.",
     "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "데이터베이스가 트랜잭션 파일 잠금에 사용됩니다. 성능을 향상하려면, 가능한 경우 memcache를 설정하십시오.",
     "Forwarded for headers" : "헤더에 전달됨",
     "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "\"trusted_proxies\" 설정이 바르지 않습니다. 배열(array) 형식으로 설정해야 합니다.",
@@ -185,8 +182,8 @@ OC.L10N.register(
     "Memcache" : "Memcache",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "메모리 캐시가 설정되지 않았습니다. 성능 향상을 위해, 가능한 경우 memcache를 설정하십시오.",
     "Configured" : "설정됨",
-    "MySQL Unicode support" : "MySQL 유니코드 지원",
     "You are not using MySQL" : "MySQL을 사용하고 있지 않습니다",
+    "MySQL Unicode support" : "MySQL 유니코드 지원",
     "MySQL is used as database and does support 4-byte characters" : "MySQL이 데이터베이스로 사용되고 있으며 4바이트 문자를 지원합니다",
     "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL이 데이터베이스로 사용되고 있으나 4바이트 문자를 지원하지 않고 있습니다. 파일 이름이나 댓글 등에 Emoji와 같은 4바이트 문자를 문제 없이 사용하기 위해, MySQL에서 4바이트 문자 지원을 활성화하길 권장합니다.",
     "Overwrite CLI URL" : "CLI URL 덮어쓰기",
@@ -316,7 +313,6 @@ OC.L10N.register(
     "Show details for {appName} app" : "{appName} 앱에 대한 상세 정보 보기",
     "Update to {update}" : "{update}(으)로 업데이트",
     "Remove" : "삭제",
-    "Disable" : "사용 안함",
     "Featured" : "추천",
     "This app is supported via your current Nextcloud subscription." : "이 앱은 당신의 현재 Nextcloud 구독을 통해 지원됩니다.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "추천 앱은 커뮤니티에서 개발했습니다. 이들은 생산성 업무에 있어 중심적인 기능을 담당하며 즉각 사용될 수 있습니다.",
@@ -338,12 +334,20 @@ OC.L10N.register(
     "Next slide" : "다음 슬라이드",
     "Choose slide to display" : "표시할 슬라이드 선택",
     "{index} of {total}" : "{total}개 중 {index}",
+    "Daemon" : "데몬",
+    "Deploy Daemon" : "배포 데몬",
+    "Type" : "종류",
+    "Display Name" : "표시 이름",
+    "GPUs support" : "GPU 지원<br>",
+    "Compute device" : "컴퓨팅 장치",
     "Description" : "설명",
     "Details" : "자세히",
     "All" : "모두",
     "Limit app usage to groups" : "앱 사용을 그룹으로 제한합니다.",
     "No results" : "결과 없음",
     "Update to {version}" : "{version}(으)로 업데이트",
+    "Default Deploy daemon is not accessible" : "기본 배포 데몬에 액세스할 수 없음",
+    "Delete data on remove" : "제거 시 데이터 삭제",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
@@ -454,8 +458,6 @@ OC.L10N.register(
     "Error removing profile picture" : "프로필 사진 삭제 중 오류 발생",
     "Your biography" : "내 소개문구",
     "You are a member of the following groups:" : "당신은 다음 그룹의 멤버입니다:",
-    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>를 사용하고 있습니다.",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다.",
     "Your full name" : "내 전체 이름",
     "Primary email for password reset and notifications" : "암호 초기화 및 알림 수신용 주 이메일 주소",
     "Email options" : "이메일 옵션",
@@ -593,12 +595,12 @@ OC.L10N.register(
     "About" : "정보",
     "Full name" : "전체 이름",
     "Additional email" : "추가 이메일",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (예: Mastodon)",
     "Headline" : "표제",
     "Organisation" : "조직",
     "Phone number" : "휴대폰 번호",
     "Role" : "직책",
     "X (formerly Twitter)" : "X (구 Twitter)",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (예: Mastodon)",
     "Website" : "웹사이트",
     "Profile visibility" : "프로필 표시 여부",
     "Locale" : "지역",
@@ -614,7 +616,10 @@ OC.L10N.register(
     "Show to everyone" : "전체 공개",
     "Show to logged in accounts only" : "로그인된 계정에 공개",
     "Hide" : "비공개",
+    "manual-install apps cannot be updated" : "수동 설치 앱은 업데이트 할 수 없음",
+    "Deploy and Enable" : "배포 및 활성화",
     "Download and enable" : "다운로드 및 사용",
+    "Disable" : "사용 안함",
     "Allow untested app" : "확인되지 않은 앱 허용",
     "The app will be downloaded from the App Store" : "이 앱이 앱 스토어에서 다운로드됩니다.",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
@@ -623,8 +628,9 @@ OC.L10N.register(
     "Could not register device: Probably already registered" : "기기를 등록할 수 없음: 이미 등록된 기기인 것 같습니다",
     "Could not register device" : "기기를 등록할 수 없음",
     "An error occurred during the request. Unable to proceed." : "요청을 보내는 도중 오류가 발생하였습니다. 더 이상 진행할 수 없습니다.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
+    "The app has been enabled but needs to be updated." : "앱이 활성화 되었으나 업데이트가 필요합니다.",
     "Error: This app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다.",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
     "Do you really want to wipe your data from this device?" : "정말 이 기기로 부터 데이터를  지우시겠습니까?",
     "Confirm wipe" : "삭제 완료",
     "Could not delete the app token" : "앱 토큰을 삭제할 수 없음",
@@ -655,6 +661,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
     "Test and verify email settings" : "이메일 설정 테스트 및 검증",
+    "Security & setup warnings" : "보안 및 설치 경고",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "정확한 설정은 인스턴스의 보안과 성능에 중요합니다. 아래의 자동 진단 결과를 참조하여 최적의 설정으로 조정하십시오. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
     "All checks passed." : "모든 검사를 통과했습니다.",
     "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 오류가 있습니다.",
@@ -665,7 +672,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "당신의 조직에서 Nextcloud를 사용해야 할 이유",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
     "Like our Facebook page" : "Facebook 페이지에서 좋아요 누르기",
-    "Follow us on Twitter" : "트위터에서 팔로하기",
     "Follow us on Mastodon" : "Mastodon에서 팔로우하기",
     "Check out our blog" : "블로그 확인하기",
     "Subscribe to our newsletter" : "뉴스레터 구독하기",
@@ -684,6 +690,8 @@ OC.L10N.register(
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "현재 사용자가 불러온 SSL 인증서 중 Nextcloud 21과 함께 사용할 수 없는 것이 있습니다. 이러한 인증서는 커맨드라인 명령어 \"occ security:certificates:import\"로 불러올 수 있습니다. 데이터 디렉토리 내부에 있는 해당 인증서의 경로가 아래에 표시됩니다.",
     "Missing optional index \"%s\" in table \"%s\"." : "표 \"%s\"의 optional index \"%s\"이(가) 사라졌습니다",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "데이터베이스에 일부 인덱스가 없습니다. 큰 테이블에 인덱스를 추가하는 데 시간이 걸리기 때문에 자동으로 추가하지 않았습니다. 명령행에서 \"occ db:add-missing-indices\" 명령을 실행하여 인스턴스를 실행하는 동안 수동으로 인덱스를 추가할 수 있습니다. 해당 테이블에 인덱스를 추가하면 질의 속도가 다시 빨라집니다.",
+    "File locking" : "파일 잠금",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "트랜잭션 파일 잠금이 비활성화되어 있어 동시 접근 시 문제가 발생할 수 있습니다. config.php에서 \"filelocking.enabled\"를 활성화하여 이 문제를 방지하십시오.",
     "Could not check for JavaScript support. Please check manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "JavaScript 지원 여부를 확인할 수 없습니다. 이 웹 서버가 JacaScript MIME 타입을 통해 `.mjs` 파일을 제공할 경우 수동으로 이를 확인하십시오.",
     "MySQL unicode support" : "MySQL 유니코드 지원",
     "Overwrite cli URL" : "CLI URL 덮어쓰기",
@@ -708,6 +716,8 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"{user}\"." : "시스템 사용자 \"{user}\"(으)로 cron.php를 실행해야 합니다.",
     "Enable or disable profile by default for new users." : "신규 사용자에 대한 프로필 기본 사용 여부를 설정하십시오.",
     "You are about to remove the group \"{group}\". The users will NOT be deleted." : "그룹 \"{group}\"을(를) 지우려고 합니다. 그룹의 사용자는 삭제되지 않습니다.",
+    "You are using <strong>{usage}</strong>" : "<strong>{usage}</strong>를 사용하고 있습니다.",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "전체 <strong>{totalSpace}</strong> 중 <strong>{usage}</strong>(<strong>{usageRelative}%</strong>)를 사용하고 있습니다.",
     "Additional emails" : "추가 이메일",
     "Enable Profile" : "프로필 활성화",
     "No users" : "사용자 없음",
@@ -750,6 +760,7 @@ OC.L10N.register(
     "Show to logged in users only" : "로그인된 사용자에게 공개",
     "Nextcloud help resources" : "Nextcloud 도움말 자원",
     "SMTP Username" : "SMTP 사용자 이름",
+    "Follow us on Twitter" : "트위터에서 팔로하기",
     "Active accounts" : "활성화된 계정"
 },
 "nplurals=1; plural=0;");
