@@ -12,6 +12,9 @@ OC.L10N.register(
     "The given color is invalid" : "Задан неправильный цвет",
     "Disable-user-theming should be true or false" : "Disable-user-theming должен быть true или false",
     "Saved" : "Сохранено",
+    "Invalid app given" : "Указано неверное приложение.",
+    "Invalid type for setting \"defaultApp\" given" : "Указан неверный тип для настройки \"defaultApp\"",
+    "Invalid setting key" : "Неверный ключ настройки",
     "The file was uploaded" : "Файл был загружен",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размер переданного файла превышает установленный предел upload_max_filesize в php.ini:",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размер переданного файла превышает установленный предел MAX_FILE_SIZE в HTML-форме",
@@ -26,6 +29,7 @@ OC.L10N.register(
     "Appearance and accessibility" : "Внешний вид и доступность",
     "PHP Imagick module" : "PHP модуль Imagick",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Для создания значка favicon приложением «Оформления» необходимо установить и активировать модуль «imagic» подсистемы PHP. ",
+    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль PHP \"imagick\" в данном случае не имеет поддержки SVG. Для лучшей совместимости рекомендуется его установить.",
     "Dark theme with high contrast mode" : "Темная тема с режимом высокой контрастности",
     "Enable dark high contrast mode" : "Включить темную тему в режиме высокой контрастности",
     "Similar to the high contrast mode, but with dark colours." : "Аналогично режиму высокой контрастности, но с использованием темных цветов.",
@@ -83,6 +87,7 @@ OC.L10N.register(
     "Disable all keyboard shortcuts" : "Отключить все сочетания клавиш",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Доступная среда очень важна для нас. При разработке мы следуем веб-стандартам, контролируя возможность пользования всем сервисом без помощи мыши и с использованием вспомогательных программ, например, выполняющих чтение с экрана. Мы стремимся к выполнению рекомендаций {guidelines}Руководства доступности Веб-Контента{linkend} 2.1 на уровне АА, а при использовании режима высокой контрастности  — даже на уровне ААА.",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "При обнаружении ошибок, не стесняйтесь сообщать о них {issuetracker}на наш форум{linkend}. Если Вы заинтересованы в продвижении проекта присоединяйтесь к {designteam}нашей команде дизайнеров{linkend}!",
+    "Current selected app: {app}, position {position} of {total}" : "Текущее выбранное приложение: {app}, позиция {position} из {total}",
     "Move up" : "Переместить выше",
     "Move down" : "Переместить ниже",
     "Custom background" : "Пользовательский фон",
@@ -104,6 +109,11 @@ OC.L10N.register(
     "Default app" : "Приложение по умолчанию",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Приложение по умолчанию - это приложение, которое открывается, например, после входа в систему или при нажатии на логотип в меню.",
     "Use custom default app" : "Использовать пользовательское приложение по умолчанию",
+    "Global default app" : "Глобальное приложение по умолчанию",
+    "Global default apps" : "Глобальные приложения по умолчанию",
+    "Default app priority" : "Приоритет приложения по умолчанию",
+    "If an app is not enabled for a user, the next app with lower priority is used." : "Если приложение не включено для пользователя, используется следующее приложение с более низким приоритетом.",
+    "Could not set global default apps" : "Не удалось установить глобальные приложения по умолчанию.",
     "Select a custom color" : "Выберать собственный цвет",
     "Reset to default" : "Сбросить изменения",
     "Upload" : "Отправить",
